You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [12/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ s...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Min.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Min.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Min.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Min.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.rank;
+package org.apache.commons.math3.stat.descriptive.rank;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the minimum of the available values.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Percentile.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Percentile.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Percentile.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Percentile.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.rank;
+package org.apache.commons.math3.stat.descriptive.rank;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.AbstractUnivariateStatistic;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.AbstractUnivariateStatistic;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Provides percentile computation.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Summary statistics based on ranks.
  */
-package org.apache.commons.math.stat.descriptive.rank;
+package org.apache.commons.math3.stat.descriptive.rank;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Product.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Product.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Product.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Product.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.summary;
+package org.apache.commons.math3.stat.descriptive.summary;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.stat.descriptive.WeightedEvaluation;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.stat.descriptive.WeightedEvaluation;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the product of the available values.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Sum.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Sum.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Sum.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/Sum.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.summary;
+package org.apache.commons.math3.stat.descriptive.summary;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfLogs.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfLogs.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfSquares.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfSquares.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.summary;
+package org.apache.commons.math3.stat.descriptive.summary;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the sum of the squares of the available values.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Other summary statistics.
  */
-package org.apache.commons.math.stat.descriptive.summary;
+package org.apache.commons.math3.stat.descriptive.summary;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/ChiSquareTest.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/ChiSquareTest.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/ChiSquareTest.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/ChiSquareTest.java Tue Feb 14 16:17:55 2012
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
-import org.apache.commons.math.distribution.ChiSquaredDistribution;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.ZeroException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.distribution.ChiSquaredDistribution;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.ZeroException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Implements Chi-Square test statistics.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/MannWhitneyUTest.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/MannWhitneyUTest.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/MannWhitneyUTest.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/MannWhitneyUTest.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
-import org.apache.commons.math.distribution.NormalDistribution;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.ranking.NaNStrategy;
-import org.apache.commons.math.stat.ranking.NaturalRanking;
-import org.apache.commons.math.stat.ranking.TiesStrategy;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.distribution.NormalDistribution;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.ranking.NaNStrategy;
+import org.apache.commons.math3.stat.ranking.NaturalRanking;
+import org.apache.commons.math3.stat.ranking.TiesStrategy;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * An implementation of the Mann-Whitney U test (also called Wilcoxon rank-sum test).

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/OneWayAnova.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/OneWayAnova.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TTest.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TTest.java Tue Feb 14 16:17:55 2012
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
-import org.apache.commons.math.distribution.TDistribution;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.StatUtils;
-import org.apache.commons.math.stat.descriptive.StatisticalSummary;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.distribution.TDistribution;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.StatUtils;
+import org.apache.commons.math3.stat.descriptive.StatisticalSummary;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * An implementation for Student's t-tests.
@@ -49,7 +49,7 @@ import org.apache.commons.math.util.Fast
  * <p>
  * Input to tests can be either <code>double[]</code> arrays or
  * {@link StatisticalSummary} instances.</p><p>
- * Uses commons-math {@link org.apache.commons.math.distribution.TDistribution}
+ * Uses commons-math {@link org.apache.commons.math3.distribution.TDistribution}
  * implementation to estimate exact p-values.</p>
  *
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TestUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TestUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TestUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TestUtils.java Tue Feb 14 16:17:55 2012
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
 import java.util.Collection;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.ZeroException;
-import org.apache.commons.math.stat.descriptive.StatisticalSummary;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.ZeroException;
+import org.apache.commons.math3.stat.descriptive.StatisticalSummary;
 
 /**
  * A collection of static methods to create inference test instances or to
@@ -57,7 +57,7 @@ public class TestUtils  {
     // CHECKSTYLE: stop JavadocMethodCheck
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#homoscedasticT(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#homoscedasticT(double[], double[])
      */
     public static double homoscedasticT(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NumberIsTooSmallException {
@@ -65,7 +65,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#homoscedasticT(org.apache.commons.math.stat.descriptive.StatisticalSummary, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#homoscedasticT(org.apache.commons.math3.stat.descriptive.StatisticalSummary, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double homoscedasticT(final StatisticalSummary sampleStats1,
                                         final StatisticalSummary sampleStats2)
@@ -74,7 +74,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#homoscedasticTTest(double[], double[], double)
+     * @see org.apache.commons.math3.stat.inference.TTest#homoscedasticTTest(double[], double[], double)
      */
     public static boolean homoscedasticTTest(final double[] sample1, final double[] sample2,
                                              final double alpha)
@@ -84,7 +84,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#homoscedasticTTest(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#homoscedasticTTest(double[], double[])
      */
     public static double homoscedasticTTest(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NumberIsTooSmallException, MaxCountExceededException {
@@ -92,7 +92,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#homoscedasticTTest(org.apache.commons.math.stat.descriptive.StatisticalSummary, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#homoscedasticTTest(org.apache.commons.math3.stat.descriptive.StatisticalSummary, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double homoscedasticTTest(final StatisticalSummary sampleStats1,
                                             final StatisticalSummary sampleStats2)
@@ -101,7 +101,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#pairedT(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#pairedT(double[], double[])
      */
     public static double pairedT(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NoDataException,
@@ -110,7 +110,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#pairedTTest(double[], double[], double)
+     * @see org.apache.commons.math3.stat.inference.TTest#pairedTTest(double[], double[], double)
      */
     public static boolean pairedTTest(final double[] sample1, final double[] sample2,
                                       final double alpha)
@@ -120,7 +120,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#pairedTTest(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#pairedTTest(double[], double[])
      */
     public static double pairedTTest(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NoDataException, DimensionMismatchException,
@@ -129,7 +129,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#t(double, double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#t(double, double[])
      */
     public static double t(final double mu, final double[] observed)
         throws NullArgumentException, NumberIsTooSmallException {
@@ -137,7 +137,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#t(double, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#t(double, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double t(final double mu, final StatisticalSummary sampleStats)
         throws NullArgumentException, NumberIsTooSmallException {
@@ -145,7 +145,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#t(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#t(double[], double[])
      */
     public static double t(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NumberIsTooSmallException {
@@ -153,7 +153,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#t(org.apache.commons.math.stat.descriptive.StatisticalSummary, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#t(org.apache.commons.math3.stat.descriptive.StatisticalSummary, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double t(final StatisticalSummary sampleStats1,
                            final StatisticalSummary sampleStats2)
@@ -162,7 +162,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double, double[], double)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double, double[], double)
      */
     public static boolean tTest(final double mu, final double[] sample, final double alpha)
         throws NullArgumentException, NumberIsTooSmallException,
@@ -171,7 +171,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double, double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double, double[])
      */
     public static double tTest(final double mu, final double[] sample)
         throws NullArgumentException, NumberIsTooSmallException,
@@ -180,7 +180,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double, org.apache.commons.math.stat.descriptive.StatisticalSummary, double)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double, org.apache.commons.math3.stat.descriptive.StatisticalSummary, double)
      */
     public static boolean tTest(final double mu, final StatisticalSummary sampleStats,
                                 final double alpha)
@@ -190,7 +190,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double tTest(final double mu, final StatisticalSummary sampleStats)
         throws NullArgumentException, NumberIsTooSmallException,
@@ -199,7 +199,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double[], double[], double)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double[], double[], double)
      */
     public static boolean tTest(final double[] sample1, final double[] sample2,
                                 final double alpha)
@@ -209,7 +209,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(double[], double[])
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(double[], double[])
      */
     public static double tTest(final double[] sample1, final double[] sample2)
         throws NullArgumentException, NumberIsTooSmallException,
@@ -218,7 +218,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(org.apache.commons.math.stat.descriptive.StatisticalSummary, org.apache.commons.math.stat.descriptive.StatisticalSummary, double)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(org.apache.commons.math3.stat.descriptive.StatisticalSummary, org.apache.commons.math3.stat.descriptive.StatisticalSummary, double)
      */
     public static boolean tTest(final StatisticalSummary sampleStats1,
                                 final StatisticalSummary sampleStats2,
@@ -229,7 +229,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.TTest#tTest(org.apache.commons.math.stat.descriptive.StatisticalSummary, org.apache.commons.math.stat.descriptive.StatisticalSummary)
+     * @see org.apache.commons.math3.stat.inference.TTest#tTest(org.apache.commons.math3.stat.descriptive.StatisticalSummary, org.apache.commons.math3.stat.descriptive.StatisticalSummary)
      */
     public static double tTest(final StatisticalSummary sampleStats1,
                                final StatisticalSummary sampleStats2)
@@ -239,7 +239,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquare(double[], long[])
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquare(double[], long[])
      */
     public static double chiSquare(final double[] expected, final long[] observed)
         throws NotPositiveException, NotStrictlyPositiveException,
@@ -248,7 +248,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquare(long[][])
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquare(long[][])
      */
     public static double chiSquare(final long[][] counts)
         throws NullArgumentException, NotPositiveException,
@@ -257,7 +257,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquareTest(double[], long[], double)
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquareTest(double[], long[], double)
      */
     public static boolean chiSquareTest(final double[] expected, final long[] observed,
                                         final double alpha)
@@ -267,7 +267,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquareTest(double[], long[])
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquareTest(double[], long[])
      */
     public static double chiSquareTest(final double[] expected, final long[] observed)
         throws NotPositiveException, NotStrictlyPositiveException,
@@ -276,7 +276,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquareTest(long[][], double)
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquareTest(long[][], double)
      */
     public static boolean chiSquareTest(final long[][] counts, final double alpha)
         throws NullArgumentException, DimensionMismatchException,
@@ -285,7 +285,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.ChiSquareTest#chiSquareTest(long[][])
+     * @see org.apache.commons.math3.stat.inference.ChiSquareTest#chiSquareTest(long[][])
      */
     public static double chiSquareTest(final long[][] counts)
         throws NullArgumentException, DimensionMismatchException,
@@ -294,7 +294,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.UnknownDistributionChiSquareTest#chiSquareDataSetsComparison(long[], long[])
+     * @see org.apache.commons.math3.stat.inference.UnknownDistributionChiSquareTest#chiSquareDataSetsComparison(long[], long[])
      *
      * @since 1.2
      */
@@ -305,7 +305,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.UnknownDistributionChiSquareTest#chiSquareTestDataSetsComparison(long[], long[])
+     * @see org.apache.commons.math3.stat.inference.UnknownDistributionChiSquareTest#chiSquareTestDataSetsComparison(long[], long[])
      *
      * @since 1.2
      */
@@ -317,7 +317,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.UnknownDistributionChiSquareTest#chiSquareTestDataSetsComparison(long[], long[], double)
+     * @see org.apache.commons.math3.stat.inference.UnknownDistributionChiSquareTest#chiSquareTestDataSetsComparison(long[], long[], double)
      *
      * @since 1.2
      */
@@ -330,7 +330,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.OneWayAnova#anovaFValue(Collection)
+     * @see org.apache.commons.math3.stat.inference.OneWayAnova#anovaFValue(Collection)
      *
      * @since 1.2
      */
@@ -340,7 +340,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.OneWayAnova#anovaPValue(Collection)
+     * @see org.apache.commons.math3.stat.inference.OneWayAnova#anovaPValue(Collection)
      *
      * @since 1.2
      */
@@ -351,7 +351,7 @@ public class TestUtils  {
     }
 
     /**
-     * @see org.apache.commons.math.stat.inference.OneWayAnova#anovaTest(Collection,double)
+     * @see org.apache.commons.math3.stat.inference.OneWayAnova#anovaTest(Collection,double)
      *
      * @since 1.2
      */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/WilcoxonSignedRankTest.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/WilcoxonSignedRankTest.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/WilcoxonSignedRankTest.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/WilcoxonSignedRankTest.java Tue Feb 14 16:17:55 2012
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
-import org.apache.commons.math.distribution.NormalDistribution;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.stat.ranking.NaNStrategy;
-import org.apache.commons.math.stat.ranking.NaturalRanking;
-import org.apache.commons.math.stat.ranking.TiesStrategy;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.distribution.NormalDistribution;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.stat.ranking.NaNStrategy;
+import org.apache.commons.math3.stat.ranking.NaturalRanking;
+import org.apache.commons.math3.stat.ranking.TiesStrategy;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * An implementation of the Wilcoxon signed-rank test.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/package-info.java Tue Feb 14 16:17:55 2012
@@ -20,4 +20,4 @@
  *      construction.
  *
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Data storage, manipulation and summary routines.
  */
-package org.apache.commons.math.stat;
+package org.apache.commons.math3.stat;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaNStrategy.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaNStrategy.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaNStrategy.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaNStrategy.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.ranking;
+package org.apache.commons.math3.stat.ranking;
 
 /**
  * Strategies for handling NaN values in rank transformations.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaturalRanking.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaturalRanking.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaturalRanking.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/NaturalRanking.java Tue Feb 14 16:17:55 2012
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.ranking;
+package org.apache.commons.math3.stat.ranking;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.commons.math.exception.MathInternalError;
-import org.apache.commons.math.random.RandomData;
-import org.apache.commons.math.random.RandomDataImpl;
-import org.apache.commons.math.random.RandomGenerator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math3.random.RandomData;
+import org.apache.commons.math3.random.RandomDataImpl;
+import org.apache.commons.math3.random.RandomGenerator;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/RankingAlgorithm.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/RankingAlgorithm.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/RankingAlgorithm.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/RankingAlgorithm.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.ranking;
+package org.apache.commons.math3.stat.ranking;
 
 /**
  * Interface representing a rank transformation.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/TiesStrategy.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/TiesStrategy.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/TiesStrategy.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/TiesStrategy.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.ranking;
+package org.apache.commons.math3.stat.ranking;
 
 /**
  * Strategies for handling tied values in rank transformations.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/ranking/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,4 +19,4 @@
  *      Classes providing rank transformations.
  *
  */
-package org.apache.commons.math.stat.ranking;
+package org.apache.commons.math3.stat.ranking;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/AbstractMultipleLinearRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/AbstractMultipleLinearRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/AbstractMultipleLinearRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/AbstractMultipleLinearRegression.java Tue Feb 14 16:17:55 2012
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.linear.NonSquareMatrixException;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.RealVector;
-import org.apache.commons.math.linear.ArrayRealVector;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.linear.NonSquareMatrixException;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.RealVector;
+import org.apache.commons.math3.linear.ArrayRealVector;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Abstract base class for implementations of MultipleLinearRegression.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/GLSMultipleLinearRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/GLSMultipleLinearRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/GLSMultipleLinearRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/GLSMultipleLinearRegression.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
-import org.apache.commons.math.linear.LUDecomposition;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.RealVector;
+import org.apache.commons.math3.linear.LUDecomposition;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.RealVector;
 
 /**
  * The GLS implementation of the multiple linear regression.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MillerUpdatingRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MillerUpdatingRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MillerUpdatingRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MillerUpdatingRegression.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
 import java.util.Arrays;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.Precision;
-import org.apache.commons.math.util.MathArrays;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math3.util.MathArrays;
 
 /**
  * <p>This class is a concrete implementation of the {@link UpdatingMultipleLinearRegression} interface.</p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/ModelSpecificationException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/ModelSpecificationException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/ModelSpecificationException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/ModelSpecificationException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.Localizable;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.Localizable;
 
 /**
  * Exception thrown when a regression model is not correctly specified.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MultipleLinearRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MultipleLinearRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MultipleLinearRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/MultipleLinearRegression.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
 /**
  * The multiple linear regression can be represented in matrix-notation.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/OLSMultipleLinearRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/OLSMultipleLinearRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/OLSMultipleLinearRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/OLSMultipleLinearRegression.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.LUDecomposition;
-import org.apache.commons.math.linear.QRDecomposition;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.linear.RealVector;
-import org.apache.commons.math.stat.StatUtils;
-import org.apache.commons.math.stat.descriptive.moment.SecondMoment;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.LUDecomposition;
+import org.apache.commons.math3.linear.QRDecomposition;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.linear.RealVector;
+import org.apache.commons.math3.stat.StatUtils;
+import org.apache.commons.math3.stat.descriptive.moment.SecondMoment;
 
 /**
  * <p>Implements ordinary least squares (OLS) to estimate the parameters of a

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/RegressionResults.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/RegressionResults.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/RegressionResults.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/RegressionResults.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
 import java.io.Serializable;
 import java.util.Arrays;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathArrays;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathArrays;
 
 /**
  * Results of a Multiple Linear Regression model fit.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/SimpleRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/SimpleRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/SimpleRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/SimpleRegression.java Tue Feb 14 16:17:55 2012
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.distribution.TDistribution;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.distribution.TDistribution;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.Precision;
 
 /**
  * Estimates an ordinary least squares regression model
@@ -674,7 +674,7 @@ public class SimpleRegression implements
      * <code>Double.NaN</code>.</p>
      *
      * @return significance level for slope/correlation
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the significance level can not be computed.
      */
     public double getSignificance() {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/UpdatingMultipleLinearRegression.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/UpdatingMultipleLinearRegression.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/UpdatingMultipleLinearRegression.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/UpdatingMultipleLinearRegression.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;
 
 /**
  * An interface for regression models allowing for dynamic updating of the data.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/regression/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,4 +19,4 @@
  *      Statistical routines involving multivariate data.
  *
  */
-package org.apache.commons.math.stat.regression;
+package org.apache.commons.math3.stat.regression;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DctNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DctNormalization.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DctNormalization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DctNormalization.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DftNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DftNormalization.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DftNormalization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DftNormalization.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DstNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DstNormalization.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DstNormalization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/DstNormalization.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastCosineTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastCosineTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastCosineTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastCosineTransformer.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.analysis.FunctionUtils;
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.ArithmeticUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.FunctionUtils;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.complex.Complex;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * <p>
@@ -115,9 +115,9 @@ public class FastCosineTransformer imple
     /**
      * {@inheritDoc}
      *
-     * @throws org.apache.commons.math.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is
      * not a power of two plus one

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastFourierTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastFourierTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastFourierTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastFourierTransformer.java Tue Feb 14 16:17:55 2012
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
 
-import org.apache.commons.math.analysis.FunctionUtils;
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.ArithmeticUtils;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathArrays;
+import org.apache.commons.math3.analysis.FunctionUtils;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.complex.Complex;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathArrays;
 
 /**
  * <p>
@@ -397,9 +397,9 @@ public class FastFourierTransformer impl
      * @param n the number of sample points
      * @param type the type of transform (forward, inverse) to be performed
      * @return the complex transformed array
-     * @throws org.apache.commons.math.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the number of sample points {@code n} is negative
      * @throws MathIllegalArgumentException if the number of sample points
      * {@code n} is not a power of two

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastHadamardTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastHadamardTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastHadamardTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastHadamardTransformer.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.analysis.FunctionUtils;
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.ArithmeticUtils;
+import org.apache.commons.math3.analysis.FunctionUtils;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.ArithmeticUtils;
 
 /**
  * Implements the <a href="http://www.archive.chipcenter.com/dsp/DSP000517F1.html">Fast Hadamard Transform</a> (FHT).
@@ -56,9 +56,9 @@ public class FastHadamardTransformer imp
     /**
      * {@inheritDoc}
      *
-     * @throws org.apache.commons.math.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is
      * not a power of two

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastSineTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastSineTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastSineTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/FastSineTransformer.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.analysis.FunctionUtils;
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.ArithmeticUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.FunctionUtils;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.complex.Complex;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * <p>
@@ -119,9 +119,9 @@ public class FastSineTransformer impleme
      *
      * This implementation enforces {@code f(x) = 0.0} at {@code x = 0.0}.
      *
-     * @throws org.apache.commons.math.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is
      * not a power of two

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/RealTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/RealTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/RealTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/RealTransformer.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
+import org.apache.commons.math3.analysis.UnivariateFunction;
 
 /**
  * <p>Interface for one-dimensional data sets transformations producing real
@@ -25,7 +25,7 @@ import org.apache.commons.math.analysis.
  * {@link FastCosineTransformer cosine transform} or {@link
  * FastHadamardTransformer Hadamard transform}. {@link FastFourierTransformer
  * Fourier transform} is of a different kind and does not implement this
- * interface since it produces {@link org.apache.commons.math.complex.Complex}
+ * interface since it produces {@link org.apache.commons.math3.complex.Complex}
  * results instead of real ones.</p>
  *
  * @version $Id$
@@ -52,9 +52,9 @@ public interface RealTransformer  {
      * @param n the number of sample points
      * @param type the type of transform (forward, inverse) to be performed
      * @return the real transformed array
-     * @throws org.apache.commons.math.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the number of sample points is negative
      */
     double[] transform(UnivariateFunction f,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformType.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformType.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformType.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformType.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 /**
  * This enumeration defines the type of transform which is to be computed.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/TransformUtils.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.complex.Complex;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Useful functions for the implementation of various transforms.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/transform/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,4 +19,4 @@
  *     Implementations of transform methods, including Fast Fourier transforms.
  *
  */
-package org.apache.commons.math.transform;
+package org.apache.commons.math3.transform;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ArithmeticUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ArithmeticUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ArithmeticUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ArithmeticUtils.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.math.BigInteger;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Some useful, arithmetics related, additions to the built-in functions in

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigReal.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigReal.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigReal.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigReal.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 
 import java.io.Serializable;
@@ -23,8 +23,8 @@ import java.math.BigInteger;
 import java.math.MathContext;
 import java.math.RoundingMode;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Arbitrary precision decimal number.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigRealField.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigRealField.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigRealField.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/BigRealField.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Representation of real numbers with arbitrary precision field.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/CompositeFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/CompositeFormat.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/CompositeFormat.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/CompositeFormat.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ContinuedFraction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ContinuedFraction.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ContinuedFraction.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/ContinuedFraction.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Provides a generic means to evaluate continued fractions.  Subclasses simply

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DefaultTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DefaultTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DefaultTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DefaultTransformer.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NullArgumentException;
 
 /**
  * A Default NumberTransformer for java.lang.Numbers and Numeric Strings. This

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DoubleArray.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DoubleArray.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DoubleArray.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/DoubleArray.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMath.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMath.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMath.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMath.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.io.PrintStream;
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathCalc.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathCalc.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathCalc.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathCalc.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 import java.io.PrintStream;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 /** Class used to compute the classical functions tables.
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/util/FastMathLiteralArrays.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.util;
+package org.apache.commons.math3.util;
 
 /**
  * Utility class for loading tabulated data used by {@link FastMath}.
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfLogs.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfLogs.java Tue Feb 14 16:17:55 2012
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.summary;
+package org.apache.commons.math3.stat.descriptive.summary;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the sum of the natural logs for this collection of values.
  * <p>
  * Uses {@link org.apache.commons.math.util.FastMath#log(double)} to compute the logs.
  * Therefore,
  * <ul>
  * <li>If any of values are &lt; 0, the result is <code>NaN.</code></li>
@@ -14,19 +14,19 @@
  * Returns the sum of the natural logs for this collection of values.
  * <p>
- * Uses {@link org.apache.commons.math.util.FastMath#log(double)} to compute the logs.
+ * Uses {@link org.apache.commons.math3.util.FastMath#log(double)} to compute the logs.
  * Therefore,
  * <ul>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfSquares.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/summary/SumOfSquares.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/OneWayAnova.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/OneWayAnova.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.inference;
+package org.apache.commons.math3.stat.inference;
 
-import org.apache.commons.math.distribution.FDistribution;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math3.distribution.FDistribution;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
 
 import java.util.Collection;
 
@@ -34,9 +34,9 @@ import java.util.Collection;
  * <p> Tests for differences between two or more categories of univariate data
  * (for example, the body mass index of accountants, lawyers, doctors and
  * computer programmers).  When two categories are given, this is equivalent to
- * the {@link org.apache.commons.math.stat.inference.TTest}.
+ * the {@link org.apache.commons.math3.stat.inference.TTest}.
  * </p><p>
  * Uses the {@link org.apache.commons.math.distribution.FDistribution
  * commons-math F Distribution implementation} to estimate exact p-values.</p>
  * <p>This implementation is based on a description at
  * http://faculty.vassar.edu/lowry/ch13pt1.html</p>
@@ -103,7 +103,7 @@ public class OneWayAnova {
      * <code>categoryData</code> collection and each of these arrays must
      * contain at least two values.</li></ul></p><p>
      * This implementation uses the
-     * {@link org.apache.commons.math.distribution.FDistribution
+     * {@link org.apache.commons.math3.distribution.FDistribution
      * commons-math F Distribution implementation} to estimate the exact
      * p-value, using the formula<pre>
      *   p = 1 - cumulativeProbability(F)</pre>
@@ -143,7 +143,7 @@ public class OneWayAnova {
      * <li>alpha must be strictly greater than 0 and less than or equal to 0.5.
      * </li></ul></p><p>
      * This implementation uses the
-     * {@link org.apache.commons.math.distribution.FDistribution
+     * {@link org.apache.commons.math3.distribution.FDistribution
      * commons-math F Distribution implementation} to estimate the exact
      * p-value, using the formula<pre>
      *   p = 1 - cumulativeProbability(F)</pre>
@@ -34,9 +34,9 @@ import java.util.Collection;
  * </p><p>
- * Uses the {@link org.apache.commons.math.distribution.FDistribution
+ * Uses the {@link org.apache.commons.math3.distribution.FDistribution
  * commons-math F Distribution implementation} to estimate exact p-values.</p>
  * <p>This implementation is based on a description at

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TTest.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/inference/TTest.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================